
#ifndef _C10_ev454_
#define _C10_ev454_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1096_9682(EIF_REFERENCE);
extern void EIF_Minit454(void);
extern EIF_REFERENCE F88_1308(EIF_REFERENCE);
extern char *(*R7905[])();

#ifdef __cplusplus
}
#endif

#endif
